"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.publishToEventBridge = void 0;

var _highland = _interopRequireDefault(require("highland"));

var _eventbridge = _interopRequireDefault(require("../connectors/eventbridge"));

var _batch = require("./batch");

var _faults = require("./faults");

var _print = require("./print");

var _tags = require("./tags");

var _compression = require("./compression");

var _ratelimit = require("./ratelimit");

const publishToEventBridge = ({
  // eslint-disable-line import/prefer-default-export
  debug = (0, _print.debug)('eventbridge'),
  busName = process.env.BUS_NAME || 'undefined',
  source = 'custom',
  // could change this to internal vs external/ingress/egress
  eventField = 'event',
  // is often named emit
  publishRequestEntryField = 'publishRequestEntry',
  publishRequestField = 'publishRequest',
  // was inputParams
  maxPublishRequestSize = Number(process.env.PUBLISH_MAX_REQ_SIZE) || Number(process.env.MAX_REQ_SIZE) || 256 * 1024,
  batchSize = Number(process.env.PUBLISH_BATCH_SIZE) || Number(process.env.BATCH_SIZE) || 10,
  parallel = Number(process.env.PUBLISH_PARALLEL) || Number(process.env.PARALLEL) || 8,
  handleErrors = true,
  retryConfig,
  ...opt
} = {}) => {
  const connector = new _eventbridge.default({
    debug,
    retryConfig
  });

  const toPublishRequestEntry = uow => ({ ...uow,
    [publishRequestEntryField]: {
      EventBusName: busName,
      Source: source,
      DetailType: uow[eventField].type,
      Detail: JSON.stringify(uow[eventField], (0, _compression.compress)(opt))
    }
  });

  const toPublishRequest = batchUow => ({ ...batchUow,
    [publishRequestField]: {
      Entries: batchUow.batch.map(uow => uow[publishRequestEntryField])
    }
  });

  const putEvents = batchUow => {
    const p = connector.putEvents(batchUow[publishRequestField]).catch((0, _faults.rejectWithFault)(batchUow, !handleErrors)).then(publishResponse => ({ ...batchUow,
      publishResponse
    }));
    return (0, _highland.default)(p); // wrap promise in a stream
  };

  return s => s.filter(uow => uow[eventField]).map((0, _tags.adornStandardTags)(eventField)).through((0, _ratelimit.ratelimit)(opt)).map(toPublishRequestEntry).consume((0, _batch.batchWithSize)({ ...opt,
    batchSize,
    maxRequestSize: maxPublishRequestSize,
    requestEntryField: publishRequestEntryField,
    requestField: publishRequestField,
    debug
  })).map(_batch.toBatchUow).map(toPublishRequest).map(putEvents).parallel(parallel).flatMap(_batch.unBatchUow); // for cleaner logging and testing
};

exports.publishToEventBridge = publishToEventBridge;