"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.publishToSns = void 0;

var _highland = _interopRequireDefault(require("highland"));

var _sns = _interopRequireDefault(require("../connectors/sns"));

var _faults = require("./faults");

var _print = require("./print");

var _ratelimit = require("./ratelimit");

const publishToSns = ({
  // eslint-disable-line import/prefer-default-export
  debug = (0, _print.debug)('sns'),
  topicArn = process.env.TOPIC_ARN,
  messageField = 'message',
  parallel = Number(process.env.SNS_PARALLEL) || Number(process.env.PARALLEL) || 8,
  ...opt
} = {}) => {
  const connector = new _sns.default({
    debug,
    topicArn
  });

  const publish = uow => {
    const p = connector.publish(uow[messageField]).then(publishResponse => ({ ...uow,
      publishResponse
    })).catch((0, _faults.rejectWithFault)(uow));
    return (0, _highland.default)(p); // wrap promise in a stream
  };

  return s => s.through((0, _ratelimit.ratelimit)(opt)).map(publish).parallel(parallel);
};

exports.publishToSns = publishToSns;